<?php
/*------------------------------------------------
//WU-History.php
//PHP script by Jim McMurry - jmcmurry@mwt.net - jcweather.us
//Current version maintained at http://jcweather.us/scripts.php
//Version 1.0  February 18, 2008
//        1.1  February 19, 2008 - Fixed a broken link to WU & added optional selection of other stations.
//        1.2  February 20, 2008 - Fixed an obscure link bug dealing with the new "other station" option.
//        1.3  February 22, 2008 - Added option to omit cloud conditions from tabular listing.  Fixed solar & rain issue in the summary section.
//        1.4  February 22, 2008 - Supressed Solar & UV graphs in monthly & longer modes. Supressed current conditions in the summary except when viewing current day.
//        1.5  February 23, 2008 - Fixed precip error when viewing previous days.  Added optional top link in header to return to "today" when off somewhere else.
//        1.6  February 27, 2008 - Fixed some missing </b> tags that were missing in the English mode that were preventing validation.
//        1.7  March 25, 2008    - Removed a superfluous <td> tag that caused a failed validation when using the option for multiple stations.
//        1.8  April, 05, 2008   - added Settings.php awareness to script (K True/saratoga-weather.org) for Carterlake/WD/AJAX/PHP templates.
//        1.9  April 07, 2008    - Made the tabular data listing optional.
//        2.0  December 23, 2008 - Fixes bugs in code to determine units output. (Thanks to Jozef (Pinto) for finding those.
//        2.1  December 23, 2008 - Fixes the modes other than Daily that were affected.  (Jozef is now officially a co-author)
//
//Portions of the code was borrowed from:
//Weather Underground - wunderground.com
//Ken True - saratoga-weather.org
//Tom Chaplin - carterlake.org
//Kevin Reed - tnetweather.com
//and probably several others.

//This script retrieves a weather station's raw data from Weather Underground 
//and displays it in a similar way to how they do it on their site.
//Weather Underground is very willing to share the graphics and data
//on their site with those who provide weather data to them.
//In a correspondence with Ken True, John Celenza, Director of Weather 
//Technology at Wunderground stated:

//"Please feel free to use Wunderground images and data on personal sites,
//as long as you link those images to Wunderground or give direct credit.
//Something like 'This image courtesy of Weather Underground' is appropriate."

//This script does NOT generate a complete HTML page and is intended for use
//ONLY by being included in an existing webpage on your site by:
//    include("./WU-History.php"); 
 
//You'll also have to place the following in the <head> section of your calling
//page:
//   <link rel="stylesheet" type="text/css" href="./WU-History.css" />
//See the enclosed test file TestHistory.php to see how this is done.

//If your WU-history files are to be kept in a folder other than where your
//calling page is, you'll have to adjust the above.  As an example,
//if your calling page is in the root folder of your web site and the WU files
//have been placed in a folder named /abc/, the paths above would need to be
//                       ./abc/WU-History.xxx 
//If using the optional files below to place information to the right of the
//summary area, the same path will have to be used with those files as well.
//Just remember that the paths are always relative to the calling page.
   
//The supporting graphics are in the enclosed wuicons folder, and that folder 
//must be placed in the same folder with this script.  If you wish the icons 
//elsewhere, just make the appropriate changes in WU-History.css.

//Optional parameters are normally not necessary, but there are a few available:
//ID=xxxxxxx should you wish to call it with a different station ID for some reason
//day=xx for a day other than today
//month=xx for a month other than this month
//year=xxxx for a different year
//There must be a "?" to signal the beginning of the parameters and "&" between items
//So, if you wished to call it for my station and show last Christmas, you'd use
//WU-History.php?ID=KWIMAUST1&day=25&month=12&year=2007

//Folks with graphic talent may want to modify the css and create graphics in other
//colors in order to come up with different color schemes.  If you put something
//together that you'd like to share, please send me copies of the .css and the
//graphics and I'd be happy to add them to this package for others to use.

//This script Is Valid XHTML 1.0 Strict!

//settings ----------------------------- */
$timezone   = "FR";                                 // Change to your TZ.  Ken True has a list available at http://saratoga-weather.org/timezone.txt  
$WUID       = "IBELFORT2";                          // Your stations Wunderground ID
$units      = "M";                                  // Default units which are changeable at runtime.  "M" for Metric, "E" for English or "B" for Both
$birthday   = "29-12-2008";                         // Stations first day of operation format dd-mm-yyyy.  This will determine years on the date selector.
$gwidth     = "500";                                // Width of the graph - normally 500
$gtemp      = true;                                 // =true if you want the temperature graph =false if no
$gpress     = true;                                 // =true if baro graph =false if no
$gwind      = false;                                // =true if wind velocity graph =false if no
$gwindir    = false;                                // =true if wind direction graph =false if no
$grain      = true;                                 // =true if rain graph =false if no
$gsolar     = false;                                // =true if solar graph =false if no
$guv        = false;                                // =true if UV graph =false if no
$pwidth     = "100%";                               // The width of the summary and graph portion of the page (% or px). Normally 100%
// Optional header info
$header     = true;                                 // true if you wish to use it
$Langtitle  = "Historique des mesures  Evette-Salbert"; // The Bold text at the top
$LcurDay    = "Retour aux mesures actuelles";       // The link back to the current day if off in one of the other modes.  "" to disable it.
// Optional footer bar
$footer     = true;                                 // true if you wish to have the colored footer bar at the bottom
$LangFtext  = "Observations mto  Evette-Salbert (Belfort) - France"; // Anything you wish or "" for a plain bar
// Optional content to be placed to the right of the Summary/Graph portion of the page
$inboxfile  = "";                                   // A file of html to be placed in the right outlined box (default : "./top.htm").  Make it "" if not using, or just don't have a file available.
$outboxfile = "";                                   // Same but for the area below the right blue box (default : "./bottom.htm").  Paths to the files must be relative to the calling page.
// Optional "Return to Top" link on the right side
$toTop      = true;                                 // Most will want this, but some folks have alternative methods. 
$LtopPg     = "Retour haut de page";
// Optional selector for other PWS data
$selOthers  = false;                                // true if you wish to show other stations, false if not 
$otherIds   = array('KWIMAUST1', 'ISILKEBO2', 'KWIKENDA1');  // Only works for PWS - Not Airports!
$otherLocat = array('Mauston, WI', 'Silkeborg, DK', 'Kendall, WI'); 
// Option to not show sky conditions in the daily tabular listing
$skipSky    = true;                                 // true to skip the last two columns, false to include them
// Option to not show the tabular data
$skipTab    = false;                                // true if you wish to suppress the tabular data
//
// Language changes follow.  If unsure about any of them, try it and see what happens.
$mnthname     = array('Nant', 'Janvier', 'Fvrier', 'Mars', 'Avril', 'Mai', 'Juin', 'Juillet', 'Aot', 'Septembre', 'Octobre', 'Novembrr', 'Decembre');
              // Next are for the Summary Table
$Langtabs     = array('Quotidien', 'Hebdomadaire', 'Mensuel', 'Annuel', 'Priode au choix');  // Tabs above the Summary Table
$LangSumHeads = array("Temperature", "Point de rose", "Humidit", "Vitesse du vent", "Rafales", "Vent", "Pression", "Precipitations", "Ensoleillement");
              // Headings for the Summary Table
$LangSumCols  = array("Actuel", "Maximum", "Minimum", "Moyenne");
$LSumfor   = "Rsum";
$Lunits    = "Units";
$Lboth     = "Mtrique/US";
$Lenglish  = "US";
$Lmetric   = "Mtrique";
$Lnext     = "Suivant";
$Lprev     = "Prcdent";
$Ltarget   = array("(Jour)", "(Semaine)", "(Mois)", "(Anne)");
$Lview     = "View";
$Ltab1     = "Mesures pour";  // Next 5 for Blue bar above the Tabular listing
$Ltab2     = "Mesures hebdomadaires";
$Ltab3     = "Mesures mensuelles";
$Ltab4     = "Mesures annuelles";
$Ltab5     = "Mesures pour priode choisie";
          // Next are for the Tabular Table
$Lheadings = array('Heure', 'Temperature', 'Point de rose', 'Pression', 'Provenance du vent', 'Vitesse du vent', 'Rafales', 'Humidit', 'Pluie (par heure)', 'Conditions', 'Nuages');
          // Headings when in weekly, monthly etc modes
$Lhdngs2   = array("Temprature", "Point de rose", "Humidit", "Pression niveau mer", "Vent", "Rafales", "Precipitations");
$Lcols2    = array("high", "ave", "low", "sum"); 
$Lcommafile= "Donnes brutes";
$Lthanks   = "";
//
// end of settings
//------------------------------------------------
// overrides from Settings.php if available
global $SITE;
if (isset($SITE['tz'])) 		{$timezone = $SITE['tz'];}
if (isset($SITE['WUID']))		{$WUID = $SITE['WUID'];}
if (isset($SITE['uomTemp']))	{
  $units = preg_match('|C|i',$SITE['uomTemp']) ? 'M':'E';
}
if (isset($SITE['WUunits']))	{$units = $SITE['WUunits'];}
if (isset($SITE['WUstationname'])) {$LangFtext = $SITE['WUstationname'];}
if (isset($SITE['WUbirthday'])) {$birthday = $SITE['WUbirthday'];}
if (isset($SITE['UV']))		{$guv = $SITE['UV'];}
if (isset($SITE['SOLAR']))	{$gsolar = $SITE['SOLAR'];}
if (isset($SITE['timeFormat'])) {$timeFormat = $SITE['timeFormat'];}
// end of overrides from Settings.php if available
if (!function_exists('date_default_timezone_set')) {
	putenv("TZ=" . $timezone);
} else {
	date_default_timezone_set($timezone);
}
putenv("TZ=".$timezone);
if (isset($_REQUEST['sce']) && strtolower($_REQUEST['sce']) == 'view' ) {
//--self downloader --
   $filenameReal = __FILE__;
   $download_size = filesize($filenameReal);
   header('Pragma: public');
   header('Cache-Control: private');
   header('Cache-Control: no-cache, must-revalidate');
   header("Content-type: text/plain");
   header("Accept-Ranges: bytes");
   header("Content-Length: $download_size");
   header('Connection: close');
   readfile($filenameReal);
   exit;
}
// Set some dates
$mo = date("m");
$da = date("d");
$yr = date("Y");
$FIRST_YEAR = substr($birthday,6,4);
$LAST_YEAR = $yr;

// Defaults if called without parameters
$PHP_SELF = $_SERVER['PHP_SELF'];
if ( empty($_REQUEST['ID']) ) 
        $_REQUEST['ID']=$WUID;
if ( empty($_REQUEST['day']) ) 
        $_REQUEST['day']=$da;
if ( empty($_REQUEST['dayend']) ) 
        $_REQUEST['dayend']=$da;
if ( empty($_REQUEST['month']) ) 
        $_REQUEST['month']=$mo;
if ( empty($_REQUEST['monthend']) ) 
        $_REQUEST['monthend']=$mo;
if ( empty($_REQUEST['year']) ) 
        $_REQUEST['year']=$yr;
if ( empty($_REQUEST['yearend']) ) 
        $_REQUEST['yearend']=$yr;		
if ( empty($_REQUEST['units']) ) 
        $_REQUEST['units']=$units;
if ( empty($_REQUEST['mode']) ) 
        $_REQUEST['mode']=1;
//Pass into PHP variables
//------------------------------------------------
$WUID = $_REQUEST['ID'];
$da = $_REQUEST['day'];
$mo = $_REQUEST['month'];
$yr = $_REQUEST['year'];
$da2 = $_REQUEST['dayend'];
$mo2 = $_REQUEST['monthend'];
$yr2 = $_REQUEST['yearend'];
$units = $_REQUEST['units'];
$mode = $_REQUEST['mode'];

// Find out if it's today or in the past
$reqdate = $da . "-" . $mo . "-" . $yr;
$isToday = strtotime($reqdate) == strtotime(date("d-m-Y"));

// Gather the csv data
$WUgraphstr = "http://www.wunderground.com/cgi-bin/wxStationGraphAll";          
$WUdatastr = "http://www.wunderground.com/weatherstation/WXDailyHistory.asp";   
if ($mode == 1) {
	$wunderstring = $WUdatastr . "?ID=" . $WUID . "&month=" . $mo . "&day=" . $da . "&year=" . $yr . "&format=1&graphspan=day";    // Day
} elseif ($mode == 2) {
	$wunderstring = $WUdatastr . "?ID=" . $WUID . "&month=" . $mo . "&day=" . $da . "&year=" . $yr . "&format=1&graphspan=week";   // Week
} elseif ($mode == 3) {
	$wunderstring = $WUdatastr . "?ID=" . $WUID . "&month=" . $mo . "&day=" . $da . "&year=" . $yr . "&format=1&graphspan=month";  // Month
} elseif ($mode == 4) {
	$wunderstring = $WUdatastr . "?ID=" . $WUID . "&month=" . $mo . "&day=" . $da . "&year=" . $yr . "&format=1&graphspan=year";   // Year
} elseif ($mode == 5) {
	$wunderstring = $WUdatastr . "?ID=" . $WUID . "&month=" . $mo . "&day=" . $da . "&year=" . $yr . "&monthend=" . $mo2 . "&dayend=" . $da2 . "&yearend=" . $yr2 . "&format=1&graphspan=custom";  // Custom
}
$csvraw=getcsvWithoutHanging($wunderstring); 
$csvdata = array_pure($csvraw);             //$csvdata has headings in row 0.  Saving a copy for no good reason
$csvarray = $csvdata;
/*
if ($mode == 1) array_shift($csvarray);     // Now $csvarray has nothing but 2D data.  The other modes don't need this treatment
if ($csvarray[0][3] > 50) {                 // Use Baro  to determine whether raw data is metric or not
	$rawunits = "metric";                   // Depends on how the user's wunderground cookie is set
} else { 
	$rawunits = "english";
}
*/
if ($mode == 1){
	array_shift($csvarray);     // Now $csvarray has nothing but 2D data.  The other modes don't need this treatment
	if ($csvarray[0][3] > 50) {                 // Use Baro  to determine whether raw data is metric or not
		$rawunits = "metric";                   // Depends on how the user's wunderground cookie is set
	} else {
		$rawunits = "english";
	}
} else {
	if ($csvarray[0][10] > 50) {                // Baro is in a different position in the other modes
		$rawunits = "metric";                   
	} else {
		$rawunits = "english";
	}
}
$wunderCSVstring = str_replace("&","&amp;",$wunderstring);	// So the link to the csv output will validate
?>
<div id="wuwrap">
<table cellpadding="0" cellspacing="0" class="full" >
<tr>
  <td class="vaT" id="content" >
  <div style="margin-top: 15px;">
<?php 
if ($header) {  // This provides an option whether to show the top heading
echo '<div class = "heading">' . $Langtitle . '</div>' . "\r";
// Display link back to current day if not currently showing "today"
	if (($mode > 1 or ! $isToday) && $LcurDay <> "") {
		$callstr = $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . date("m") . '&amp;day=' . date("d") . '&amp;year=' . date("Y") . '&amp;mode=1&amp;units=' . $units;
		echo '<div class="titleBar"><a href="' . $callstr . '">' . $LcurDay . '</a></div>' . "\r";
	} else { 
		echo '	<div class="titleBar">&nbsp;</div>' . "\r"; 
	}
}
if ($mode == 1) {
	$bannerphrase = $Langtabs[0] . ' ' . $LSumfor . ' ' . $mnthname[intval($mo)] . ' ' . $da . ', ' . $yr;
} elseif ($mode == 2) {
	$bannerphrase = $Langtabs[1] . ' ' . $LSumfor . ' ' . $mnthname[intval($mo)] . ' ' . $da . ', ' . $yr;
} elseif ($mode == 3) {
	$bannerphrase = $Langtabs[2] . ' ' . $LSumfor . ' ' . $mnthname[intval($mo)] . ' ' . $yr;
} elseif ($mode == 4) {
	$bannerphrase = $Langtabs[3] . ' ' . $LSumfor . ' ' . $yr;
} else {
	$bannerphrase = $LSumfor . ' ' . $mnthname[intval($mo)] . ' ' . $da . ', ' . $yr . ' - ' . $mnthname[intval($mo2)] . ' ' . $da2 . ', ' . $yr2;
}
?>  
	<table cellspacing="0" cellpadding="0" style="width: <?php echo($pwidth); ?>;">
		<tr class="vaT">
		<td class="full">		
			<table cellspacing="0" cellpadding="0" class="colorTop">
			<tr>
			<td class="hLeft"></td>
			<td class="hCenter vaM" ><?php echo $bannerphrase; ?></td>
			<td id="unitmenu" class="hMenu taL nobr vaM  noprint myMenu" style="padding-top: 3px">
			<?php
			$callstr = $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $mo . '&amp;day=' . $da . '&amp;year=' . $yr . '&amp;mode=' . $mode . '&amp;units=';
			if ($units == "M") {
			echo $Lunits . ': &nbsp;<b>' . $Lmetric . '</b>&nbsp;&nbsp;&nbsp; <a href="' . $callstr . '&amp;units=E' . '">' . $Lenglish . '</a>&nbsp;&nbsp;&nbsp;<a href="' . $callstr . 'B">' . $Lboth . '</a>';
			} elseif ($units == "E") {
			echo $Lunits . ': &nbsp;<b>' . $Lenglish . '</b>&nbsp;&nbsp;&nbsp; <a href="' . $callstr . '&amp;units=M' . '"> ' . $Lmetric . '</a>&nbsp;&nbsp;&nbsp;<a href="' . $callstr . 'B">' . $Lboth . '</a>';
			} else {
			echo $Lunits . ': &nbsp;<b>' . $Lboth . '</b>&nbsp;&nbsp;&nbsp; <a href="' . $callstr . '&amp;units=E' . '">' . $Lenglish . '</a>&nbsp;&nbsp;&nbsp;<a href="' . $callstr . 'M">' . $Lmetric . '</a>';
			}
			?>
			</td>
			<td class="hRight"></td>
			</tr>
			<tr>
			<td class="sLeft"></td>
			<td class="sCenter"></td>
			<td class="sCenter"></td>		
			<td class="sRight"></td>
			</tr>
			</table>
		<div class="colorBox">
		<div class="selectorBox noPrint">
		<table cellspacing="0" cellpadding="0" class="full dateTable">
		<tr>
<?php		
if ($mode == 1) {
	$ndate = AddDate($mo, $da, $yr, -1);
	echo '<td class="nobr noprint"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $ndate[mon] . '&amp;day=' . $ndate[mday] . '&amp;year=' . $ndate[year] . '&amp;units=' . $units . '&amp;mode=' . $mode . '">&laquo; ' . $Lprev . ' ' . $Ltarget[0] . '</a></td>';
} elseif ($mode == 2) {
	$ndate = AddDate($mo, $da, $yr, -7);
	echo '<td class="nobr noprint"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $ndate[mon] . '&amp;day=' . $ndate[mday] . '&amp;year=' . $ndate[year] . '&amp;units=' . $units . '&amp;mode=' . $mode  . '">&laquo; ' . $Lprev . ' ' . $Ltarget[1] . '</a></td>';
} elseif ($mode == 3) {
	$ndate = AddDate($mo, $da, $yr, -30);
	echo '<td class="nobr noprint"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $ndate[mon] . '&amp;day=' . $ndate[mday] . '&amp;year=' . $ndate[year] . '&amp;units=' . $units . '&amp;mode=' . $mode  . '">&laquo; ' . $Lprev . ' ' . $Ltarget[2] . '</a></td>';
} elseif ($mode == 4) {
	$ndate = AddDate($mo, $da, $yr, -365);
	echo '<td class="nobr noprint"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $ndate[mon] . '&amp;day=' . $ndate[mday] . '&amp;year=' . $ndate[year] . '&amp;units=' . $units . '&amp;mode=' . $mode  . '">&laquo; ' . $Lprev . ' ' . $Ltarget[3] . '</a></td>';
}		
?>		
		<td class="taC full noprint">
<?php  // These are the date selectors
    echo '<form method="post" action="' . $SITE['PHPSELF'] . '" />';
    echo '<table border="0" cellpadding="0" cellspacing="0" style="margin-left: auto; margin-right: auto;">  
        <tr>'; 
	if ($selOthers) {
		echo '<td>
			<select name="ID">' . "\n";
		for ( $i = 0; $i < sizeof($otherLocat); $i ++ ) {
			echo '<option value="' . $otherIds[$i] . '"';
			if ($otherIds[$i]==$WUID) echo ' selected="selected"'; 
				echo '>' . $otherLocat[ $i ] . '</option>' . "\n";
		}
		echo '</select>
			</td>';
	}	
	echo '<td>
        <select name="month">' . "\n";
    for ( $mon = 1; $mon < 13; $mon ++ ) {
        echo '<option value="' . $mon . '"';
		if ($mon==$mo) echo ' selected="selected"'; 
			echo '>' . $mnthname[ $mon ] . '</option>' . "\n";
    }
    echo '</select>
        </td><td>
        <select name="day">' . "\n";
    for ( $dd = 1 ; $dd < 32 ; $dd ++ ) {
        echo '<option value="' . $dd . '"'; 
		if ($dd==$da) echo ' selected="selected"';  
		echo '>' . $dd . '</option>' . "\n";
    }
    echo '</select>
        </td><td>
        <select name="year">' . "\n";
    for ( $yy = $FIRST_YEAR ; $yy < $LAST_YEAR +1 ; $yy++ ) {
        echo '<option value="' . $yy . '"';
		if ($yy==$yr) echo ' selected="selected"';  
		echo '>' . $yy . '</option>' . "\n";
    }
    echo '</select>
        </td>';
if ($mode == 5) {   //Add second set here	
		echo '<td class="nobr" style="vertical-align: middle;">- TO -</td><td>
        <select name="monthend">' . "\n";
    for ( $mon2 = 1; $mon2 < 13; $mon2 ++ ) {
        echo '<option value="' . $mon2 . '"';
		if ($mon2==$mo2) echo ' selected="selected"'; 
		echo '>' . $mnthname[ $mon2 ] . '</option>' . "\n";
    }
    echo '</select>
        </td><td>
        <select name="dayend">' . "\n";
    for ( $dd2 = 1 ; $dd2 < 32 ; $dd2 ++ ) {
        echo '<option value="' . $dd2 . '"'; 
		if ($dd2==$da2) echo ' selected="selected"';  
		echo '>' . $dd2 . '</option>' . "\n";
    }
    echo '</select>
        </td><td>
        <select name="yearend">' . "\n";
    for ( $yy2 = $FIRST_YEAR ; $yy2 < $LAST_YEAR +1 ; $yy2++ ) {
        echo '<option value="' . $yy2 . '"';
		if ($yy2==$yr2) echo ' selected="selected"';  
		echo '>' . $yy2 . '</option>' . "\n";
    }
    echo '</select>
        </td>';
}
		echo '<td><input type="submit" value="' . $Lview . '" /></td>
        </tr>
        </table>' . "\n";
?>		
		</td>
<?php		
if ($mode == 1) {
	$ndate = AddDate($mo, $da, $yr, +1);
	echo '<td class="nobr noprint"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $ndate[mon] . '&amp;day=' . $ndate[mday] . '&amp;year=' . $ndate[year] . '&amp;units=' . $units . '&amp;mode=' . $mode . '">' . $Lnext . ' ' . $Ltarget[0] . ' &raquo;</a></td>';
} elseif ($mode == 2) {
	$ndate = AddDate($mo, $da, $yr, +7);
	echo '<td class="nobr noprint"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $ndate[mon] . '&amp;day=' . $ndate[mday] . '&amp;year=' . $ndate[year] . '&amp;units=' . $units . '&amp;mode=' . $mode  . '">' . $Lnext . ' ' . $Ltarget[1] . ' &raquo;</a></td>';
} elseif ($mode == 3) {
	$ndate = AddDate($mo, $da, $yr, +30);
	echo '<td class="nobr noprint"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $ndate[mon] . '&amp;day=' . $ndate[mday] . '&amp;year=' . $ndate[year] . '&amp;units=' . $units . '&amp;mode=' . $mode  . '">' . $Lnext . ' ' . $Ltarget[2] . ' &raquo;</a></td>';
} elseif ($mode == 4) {
	$ndate = AddDate($mo, $da, $yr, +365);
	echo '<td class="nobr noprint"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $ndate[mon] . '&amp;day=' . $ndate[mday] . '&amp;year=' . $ndate[year] . '&amp;units=' . $units . '&amp;mode=' . $mode  . '">' . $Lnext . ' ' . $Ltarget[3] . ' &raquo;</a></td>';
}		
?>				
		</tr>
	</table>
	<table cellspacing="0" cellpadding="0" class="full" id="typeTable">
		<tr>
<?php   // These are the daily, weekly etc tabs
$ActTab = 'class="activeTab"';		
$InacTab = 'class="inactiveTab"';		
$callstr = $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $mo . '&amp;day=' . $da . '&amp;year=' . $yr . '&amp;units=' . $units;
if ($mode == 1) { echo '<td ' . $ActTab . '>' . $Langtabs[0] . '</td>' . "\n"; } else { echo '<td ' . $InacTab . '><a href="' . $callstr . '&amp;mode=1">' . $Langtabs[0] . '</a></td>' . "\n"; }		
if ($mode == 2) { echo '<td ' . $ActTab . '>' . $Langtabs[1] . '</td>' . "\n"; } else { echo '<td ' . $InacTab . '><a href="' . $callstr . '&amp;mode=2">' . $Langtabs[1] . '</a></td>' . "\n"; }		
if ($mode == 3) { echo '<td ' . $ActTab . '>' . $Langtabs[2] . '</td>' . "\n"; } else { echo '<td ' . $InacTab . '><a href="' . $callstr . '&amp;mode=3">' . $Langtabs[2] . '</a></td>' . "\n"; }		
if ($mode == 4) { echo '<td ' . $ActTab . '>' . $Langtabs[3] . '</td>' . "\n"; } else { echo '<td ' . $InacTab . '><a href="' . $callstr . '&amp;mode=4">' . $Langtabs[3] . '</a></td>' . "\n"; }		
if ($mode == 5) { echo '<td ' . $ActTab . '>' . $Langtabs[4] . '</td>' . "\n"; } else { echo '<td ' . $InacTab . '><a href="' . $callstr . '&amp;mode=5">' . $Langtabs[4] . '</a></td>' . "\n"; }		
?>		
		</tr>
	</table>
	</div>  <!-- div class="selectorBox noPrint" -->
<!--  Begin Summary Area -->
	<table cellspacing="0" cellpadding="0" class="summaryTable tm10">
		<thead>
		<tr style="width:100%">
		<td style="width: 25%;">&nbsp;</td>		
<?php	if ($mode==1 && $isToday) echo '<td>' . $LangSumCols[0] . ':</td>'; ?>
		<td><?php echo $LangSumCols[1]; ?>:</td>
		<td><?php echo $LangSumCols[2]; ?>:</td>
		<td><?php echo $LangSumCols[3]; ?>:</td>
		</tr>
		</thead>
		<tbody>
		<tr>
		<td><?php echo $LangSumHeads[0] . ":"; ?></td>
<?php
if ($mode == 1) {
	$result=temp_stats($csvarray, 1); // Temp
	$current=convertTemps($csvarray[count($csvarray)-1][1]);
} else {
	$t = temp_stats($csvarray, 1); // Process column 1 of the raw data
	$result[0] = $t[0];            // Store just the Hi (of the Hi's)
	$t = temp_stats($csvarray, 3); // Then column 2 which are the Lo's
	$result[1] = $t[1];            // Store the Lo (of the Lo's)
	$t = temp_stats($csvarray, 2); // Lastly proces  column 3 which are the ave's
	$result[2] = $t[2];            // Store the Ave (of the Ave's)
}	
if ($units == "M") {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[2][0] . '</b> &deg;C</td>' . "\n";
} elseif ($units == "E"){
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b> &deg;F</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b> &deg;F</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][1] . '</b> &deg;F</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[2][1] . '</b> &deg;F</td>' . "\n";
} else {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b> &deg;F  /  &nbsp;<b>' . $current[0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b> &deg;F /  &nbsp;<b>' . $result[0][0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][1] . '</b> &deg;F /  &nbsp;<b>' . $result[1][0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[2][1] . '</b> &deg;F /  &nbsp;<b>' . $result[2][0] . '</b> &deg;C</td>' . "\n";
}
?>				
		</tr>
		<tr>
		<td><?php echo $LangSumHeads[1] . ":"; ?></td>
<?php
if ($mode == 1) {
	$result=temp_stats($csvarray, 2); // Dew Point
	$current=convertTemps($csvarray[count($csvarray)-1][2]);
} else {
	$t = temp_stats($csvarray, 4); 
	$result[0] = $t[0];            
	$t = temp_stats($csvarray, 6); 
	$result[1] = $t[1];            
	$t = temp_stats($csvarray, 5); 
	$result[2] = $t[2];            
}	
if ($units == "M") {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[2][0] . '</b> &deg;C</td>' . "\n";
} elseif ($units == "E"){
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b> &deg;F</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b> &deg;F</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][1] . '</b> &deg;F</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[2][1] . '</b> &deg;F</td>' . "\n";
} else {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b> &deg;F  /  &nbsp;<b>' . $current[0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b> &deg;F /  &nbsp;<b>' . $result[0][0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][1] . '</b> &deg;F /  &nbsp;<b>' . $result[1][0] . '</b> &deg;C</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[2][1] . '</b> &deg;F /  &nbsp;<b>' . $result[2][0] . '</b> &deg;C</td>' . "\n";
}
?>		
		</tr>
		<tr>
		<td><?php echo $LangSumHeads[2] . ":"; ?></td>
<?php
if ($mode == 1) {
	$result=col_stats($csvarray, 8); // Humidity
} else {
	$t = col_stats($csvarray, 7); 
	$result[0] = $t[0];            
	$t = col_stats($csvarray, 9); 
	$result[1] = $t[1];            
	$t = col_stats($csvarray, 8); 
	$result[2] = $t[2];            
}
if ($mode == 1 && $isToday) echo '<td>' . $csvarray[count($csvarray)-1][8] . '%</td>' . "\n";
echo '<td>' . $result[0] . '%</td>' . "\n";
echo '<td>' . $result[1] . '%</td>' . "\n";
echo '<td>' . round($result[2],0) . '%</td>' . "\n";
?>		
		</tr>
		<tr>
		<td><?php echo $LangSumHeads[3] . ":"; ?></td>
<?php
if ($mode == 1) {
	$result=wind_stats($csvarray, 6); // Wind Speed
	$current=convertWind($csvarray[count($csvarray)-1][6]);
} else {
	$t = wind_stats($csvarray, 12); 
	$result[0] = $t[0];            
	$result[1] = 0;            
	$t = wind_stats($csvarray, 13); 
	$result[2] = $t[2];            
}
if ($units == "M") {
	if ($mode == 1 && $isToday) 	echo '<td class="nobr"><b>' . $current[0] . '</b>km/h</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][0] . '</b>km/h</td>' . "\n";
	if ($result[1] == 0){ echo '<td>-</td>' . "\n";} else{	echo '<td class="nobr"><b>' . $result[1][0] . '</b>km/h</td>' . "\n";}
	echo '<td class="nobr"><b>' . $result[2][0] . '</b>km/h</td>' . "\n";
} elseif ($units == "E"){
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b>mph</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b>mph</td>' . "\n";
	if ($result[1] == 0){ echo '<td>-</td>' . "\n";} else{	echo '<td class="nobr"><b>' . $result[1][1] . '</b>mph</td>' . "\n";}
	echo '<td class="nobr"><b>' . $result[2][1] . '</b>mph</td>' . "\n";
} else {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b>mph  /  &nbsp;<b>' . $current[0] . '</b>km/h</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b>mph /  &nbsp;<b>' . $result[0][0] . '</b>km/h</td>' . "\n";
	echo '<td>-</td>' . "\n";	
	echo '<td class="nobr"><b>' . $result[2][1] . '</b>mph /  &nbsp;<b>' . $result[2][0] . '</b>km/h</td>' . "\n";
}
?>				
		</tr>
		<tr>
		<td><?php echo $LangSumHeads[4] . ":"; ?></td>
<?php		
if ($mode == 1) {
	$result=wind_stats($csvarray, 7); // Wind Gust
	$current=convertWind($csvarray[count($csvarray)-1][7]);
} else {
	$t = wind_stats($csvarray, 14); 
	$result[0] = $t[0];            
}
if ($units == "M") {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[0] . '</b>km/h</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][0] . '</b>km/h</td>' . "\n";
	echo '<td>-</td>' . "\n";
	echo '<td>-</td>' . "\n";
} elseif ($units == "E"){
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b>mph</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b>mph</td>' . "\n";
	echo '<td>-</td>' . "\n";
	echo '<td>-</td>' . "\n";
} else {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b>mph  /  &nbsp;<b>' . $current[0] . '</b>km/h</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b>mph /  &nbsp;<b>' . $result[0][0] . '</b>km/h</td>' . "\n";
	echo '<td>-</td>' . "\n";
	echo '<td>-</td>' . "\n";
}
?>						
		</tr>
<?php
if ($mode == 1) {
	echo '<tr>';
	echo '<td>' . $LangSumHeads[5] . '</td>';
	$result=wDirAvg($csvarray); // Wind Direction
	if ($csvarray[count($csvarray)-1][6]==0) { $current = "Calm"; } else { $current = $csvarray[count($csvarray)-1][4]; }
	if ($mode == 1 && $isToday) echo '<td>' . $current . '</td>' . "\n";
	echo '<td>-</td>' . "\n";
	echo '<td>-</td>' . "\n";
	echo '<td>' . degTotxt($result) . '</td>' . "\n";
	echo '</tr>' . "\n";
}
?>				
		<tr>
		<td><?php echo $LangSumHeads[6] . ":"; ?></td>
<?php
if ($mode == 1) {
	$result=baro_stats($csvarray, 3); // Pressure
	$current=convertBaro($csvarray[count($csvarray)-1][3]);
} else {
	$t = baro_stats($csvarray, 10); 
	$result[0] = $t[0];            
	$t = baro_stats($csvarray, 11); 
	$result[1] = $t[1];            
}
if ($units == "M") {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[0] . '</b> hPa</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][0] . '</b> hPa</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][0] . '</b> hPa</td>' . "\n";
	echo '<td>-</td>' . "\n";
} elseif ($units == "E"){
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b> in</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b> in</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][1] . '</b> in</td>' . "\n";
	echo '<td>-</td>' . "\n";
} else {
	if ($mode == 1 && $isToday) echo '<td class="nobr"><b>' . $current[1] . '</b> in  /  &nbsp;<b>' . $current[0] . '</b> hPa</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[0][1] . '</b> in /  &nbsp;<b>' . $result[0][0] . '</b> hPa</td>' . "\n";
	echo '<td class="nobr"><b>' . $result[1][1] . '</b> in /  &nbsp;<b>' . $result[1][0] . '</b> hPa</td>' . "\n";
	echo '<td>-</td>';
}
?>						
		</tr>
		<tr>
		<td><?php echo $LangSumHeads[7] . ":"; ?></td>
<?php
if ($mode == 1) {
	$current=convertRain($csvarray[count($csvarray)-1][12]);
} else {
	$current=total_rain($csvarray, 15);	
}	
	if ($units == "M") {           // Precip
		echo '<td class="nobr"><b>' . $current[0] . '</b> mm</td>';
	} elseif ($units == "E"){
		echo '<td class="nobr"><b>' . $current[1] . '</b> in</td>';
	} else {
		echo '<td class="nobr"><b>' . $current[1] . '</b> in  /  &nbsp;<b>' . $current[0] . '</b> mm</td>';
	}
?>					
		<td>&nbsp;</td>
		<td>&nbsp;</td>
<?php
if ($mode == 1 && $isToday) {		
		echo '		<td>&nbsp;</td>';
}
?>		
		</tr>
		</tbody>
	</table>
<!--  End Summary Area & Show the Graph -->
<?php	
if ($mode == 1) {
	$gphrase='type=3';  // Day
} elseif ($mode == 2) {
	$gphrase='type=2';  // Week
} elseif ($mode == 3) {
	$gphrase='type=1';  // Month
} elseif ($mode == 4) {
	$gphrase='type=0';  // Year
} elseif ($mode == 5) {
	$gphrase='type=6&amp;yearend=' . $yr2 . '&amp;monthend=' . $mo2 . '&amp;dayend=' . $da2;  // Custom
}	
?>	
	<div class="taC tm10">
	<img src="<?php echo($WUgraphstr); ?>?day=<?php echo($da); ?>&amp;year=<?php echo($yr); ?>&amp;month=<?php echo($mo); ?>&amp;ID=<?php echo($WUID); ?>&amp;width=<?php echo($gwidth); ?>&amp;showsolarradiation=<?php if ($mode < 3) echo $gsolar?'1':'0';?>&amp;showuv=<?php if ($mode < 3) echo $guv?'1':'0'; ?>&amp;showtemp=<?php echo $gtemp?'1':'0'; ?>&amp;showpressure=<?php echo $gpress?'1':'0'; ?>&amp;showwind=<?php echo $gwind?'1':'0'; ?>&amp;showwinddir=<?php echo $gwindir?'1':'0'; ?>&amp;showrain=<?php echo $grain?'1':'0'; ?>&amp;type=<?php echo($gphrase); ?>" alt="Historical Graphs" id="wxHistoryImage" />
	<div class="noGap">&nbsp;</div>
	</div>
	</div>   <!--div class="colorBox" -->
	<table cellspacing="0" cellpadding="0" class="colorBottom">
		<tr>
		<td class= "bLeft"><div></div></td>
		<td class= "bCenter full"><div></div></td>
		<td class= "bRight"><div></div></td>
		</tr>
	</table>
	<div>&nbsp;</div>
	</td>
<!--  This is the area for the blue box right of the graph -->
<?php
if (file_exists($inboxfile)) {
	echo '<td class="noPrint">';
	echo '  <div class="rightCol">';
	
	echo '  <div class="rtTop"></div>';
	
	echo '    <div class="contentBox taC">';
	include ($inboxfile);
	echo '    </div>';
	
	echo '  <div class="rtBottom"></div>';
	
	if (file_exists($outboxfile)) {
		include ($outboxfile);
	}
	echo '  </div>';
	echo '</td>';
}
?>
		</tr>
	</table>
<?php	
if ($toTop == 1) {       // Optional link to top of the page
	echo '<div class="pageTop noprint"><a href="#">' . $LtopPg . '</a></div>';
}
if (! $skipTab) {       // Begin tabular section with option to suppress
	if ($mode == 1) {
		$bannerphrase = $Ltab1 . ' ' . $mnthname[intval($mo)] . ' ' . $da . ', ' . $yr;
	} elseif ($mode == 2) {
		$bannerphrase = $Ltab2;
	} elseif ($mode == 3) {
		$bannerphrase = $Ltab3;
	} elseif ($mode == 4) {
		$bannerphrase = $Ltab4;
	} else {
		$bannerphrase = $Ltab5;
	}	
		echo '<table cellspacing="0" cellpadding="0" class="colorTop">' . "\n";
			echo '<tr>' . "\n";
				echo '<td class="hLeft"></td>' . "\n";
				echo '<td class="hCenter">' .  $bannerphrase . '</td>' . "\n";
				echo '<td class="hMenu"></td>' . "\n";
				echo '<td class="hRight"></td>' . "\n";
			echo '</tr>' . "\n";
			echo '<tr>' . "\n";
				echo '<td class="sLeft"></td>' . "\n";
				echo '<td class="sCenter"></td>' . "\n";
				echo '<td></td>' . "\n";
				echo '<td class="sRight"></td>' . "\n";
			echo '</tr>' . "\n";
		echo '</table>' . "\n";
		echo '<div class="colorBox">' . "\n";
	   // This is the lower data table when in Daily mode
	if ($mode == 1) {
		echo '<table cellspacing="0" cellpadding="0" class="dailyTable">' . "\n";
		echo '<thead>' . "\n";
		echo '<tr>' . "\n";
		echo '<td>' . $Lheadings[0] . '</td>' . "\n";
		echo '<td>' . $Lheadings[1] . '</td>' . "\n";
		echo '<td>' . $Lheadings[2] . '</td>' . "\n";
		echo '<td>' . $Lheadings[3] . '</td>' . "\n";
		echo '<td>' . $Lheadings[4] . '</td>' . "\n";
		echo '<td>' . $Lheadings[5] . '</td>' . "\n";
		echo '<td>' . $Lheadings[6] . '</td>' . "\n";
		echo '<td>' . $Lheadings[7] . '</td>' . "\n";
		echo '<td>' . $Lheadings[8] . '</td>' . "\n";
		if (! $skipSky) {
			echo '<td>' . $Lheadings[9] . '</td>' . "\n";
			echo '<td>' . $Lheadings[10] . '</td>' . "\n";
		}
		echo '</tr>' . "\n";
		echo '</thead>' . "\n";
		echo '<tbody>' . "\n";
		// Each line is 0 - 12 (13 columns) 
		$columns = 13;
		for ($row=0; $row<count($csvarray); $row++) {
			echo "<tr>" . "\n";
			for ($col=0; $col<$columns; $col++) {
				$data = $csvarray[$row][$col];      
				if ($col == 0) $data = substr($data,11,5);  //Date/Time
				if ($col == 1 || $col == 2){               // Temp or DP
					$convarray = convertTemps($data);
					if ($units == "M") {
						$data = "<b>" . $convarray[0] . "</b> &deg;C";
					} elseif ($units == "E"){
						$data = "<b>" . $convarray[1] . "</b> &deg;F";				
					} else {
						$data = "<b>" . $convarray[1] . "</b> &deg;F / &nbsp;" . "<b>" . $convarray[0] . "</b> &deg;C";
					}
				}
				if ($col == 3) {  // Baro
					$convarray = convertBaro($data);		
					if ($units == "M") {
						$data = "<b>" . $convarray[0] . "</b> hPa";
					} elseif ($units == "E"){
						$data = "<b>" . $convarray[1] . "</b> in";				
					} else {
						$data = "<b>" . $convarray[1] . "</b>in / &nbsp;" . "<b>" . $convarray[0] . "</b>hPa";
					}
				}
				if ($col == 4) { // Wind direction
					if ($csvarray[$row][$col+2]==0) $data = "Calm";
					$col++; // Skip the wind "degrees" column		
				}
				if ($col == 6 || $col == 7){  // Wind or Gust
					$convarray = convertWind($data);		
					if ($data == 0) {
						$data = "&nbsp;";
					} elseif ($units == "M") {
						$data = "<b>" . $convarray[0] . "</b> km/h";
					} elseif ($units == "E"){
						$data = "<b>" . $convarray[1] . "</b> mph";				
					} else {
						$data = "<b>" . $convarray[1] . "</b>mph / &nbsp;" . "<b>" . $convarray[0] . "</b>km/h";
					}
				}
				if ($col == 8) $data = $data . "%";  //Humidity
				if ($col == 9) {  // Rain
					$convarray = convertRain($data);		
					if ($units == "M") {
						$data = "<b>" . $convarray[0] . "</b> mm";
					} elseif ($units == "E"){
						$data = "<b>" . $convarray[1] . "</b> in";				
					} else {
						$data = "<b>" . $convarray[1] . "</b>in / &nbsp;" . "<b>" . $convarray[0] . "</b>mm";
					}
					if ($skipSky) {
						$col = $col + 2;      // Skip the last two columns
					}
				}
				// 10 - Conditions just fine the way they are
				if ($col == 11) {$col++;}  // Clouds ok the way they are and skip 0.00s
				// 12 is nothing but zeros.  Perhaps solar some day???
				echo '<td>' . $data . "</td>" . "\n";
			}  // for $col
			echo "</tr>";
		} // for $row
		echo '</tbody>';
		echo '</table>';
	} else {                   // Its weekly, monthly, yearly or custom
		if ($units == "M") {
			$tsym = "&deg;C";
			$bsym = "hPa";
			$dsym = "km/h";
			$vsym = "km";
			$rsym = "mm";
		} elseif ($units == "E") {
			$tsym = "&deg;F";
			$bsym = "in";
			$dsym = "mph";
			$vsym = "mi";
			$rsym = "in";
		} else {
			$tsym = "&deg;F / &deg;C";
			$bsym = "in / hPa";
			$dsym = "mph / km/h";
			$vsym = "mi / km";
			$rsym = "in / mm";	
		}
		$pmo = substr($csvarray[0][0], 5, 2);
		$pda = substr($csvarray[0][0], strrpos($csvarray[0][0],"-")+1, 2);
		$pyr = substr($csvarray[0][0], 0, 4);
		$columns = 16;
		$needheading = true;
		for ($row=0; $row<count($csvarray); $row++) {
			if ($needheading) {
				$pmo = substr($csvarray[$row][0], 5, 2);
				$pyr = substr($csvarray[$row][0], 0, 4);
				$col1title = $mnthname[intval($pmo)];
				echo '<table cellspacing="0" cellpadding="0" class="obsTable" style="width:100%;">' . "\n";
				echo '<thead>' . "\n";
				echo '<tr>' . "\n";
				echo '<td colspan="2">' . $pyr . '</td>' . "\n";
				echo '<td colspan="3">' . $Lhdngs2[0] . ' (' . $tsym . ')</td>' . "\n";
				echo '<td colspan="3">' . $Lhdngs2[1] . ' (' . $tsym . ')</td>' . "\n";
				echo '<td colspan="3">' . $Lhdngs2[2] . ' (%)</td>' . "\n";
				echo '<td colspan="2">' . $Lhdngs2[3] . ' (' . $bsym . ')</td>' . "\n";
				echo '<td colspan="2">' . $Lhdngs2[4] . ' (' . $dsym . ')</td>' . "\n";
				echo '<td>' . $Lhdngs2[5] . ' (' . $dsym . ')</td>' . "\n";
				echo '<td>' . $Lhdngs2[6] . ' (' . $rsym . ')</td>' . "\n";
				echo '</tr>' . "\n";
				echo '</thead>' . "\n";
				echo '<tbody>' . "\n";
				echo '<tr>' . "\n";
				echo '<td class="b HdgLt" colspan="2">' . $col1title . '</td>' . "\n";
				echo '<td class="HdgDk Left">' . $Lcols2[0] . '</td>' . "\n";
				echo '<td class="HdgDk">' . $Lcols2[1] . '</td>' . "\n";
				echo '<td class="HdgDk Right">' . $Lcols2[2] . '</td>' . "\n";
				echo '<td class="HdgLt">' . $Lcols2[0] . '</td>' . "\n";
				echo '<td class="HdgLt">' . $Lcols2[1] . '</td>' . "\n";
				echo '<td class="HdgLt">' . $Lcols2[2] . '</td>' . "\n";
				echo '<td class="HdgDk Left">' . $Lcols2[0] . '</td>' . "\n";
				echo '<td class="HdgDk">' . $Lcols2[1] . '</td>' . "\n";
				echo '<td class="HdgDk Right">' . $Lcols2[2] . '</td>' . "\n";
				echo '<td class="HdgLt">' . $Lcols2[0] . '</td>' . "\n";
				echo '<td class="taC HdgLt">' . $Lcols2[2] . '</td>' . "\n";
				echo '<td class="HdgDk Left">' . $Lcols2[0] . '</td>' . "\n";
				echo '<td class="HdgDk Right">' . $Lcols2[1] . '</td>' . "\n";
				echo '<td class="HdgLt">' . $Lcols2[0] . '</td>' . "\n";
				echo '<td class="HdgDk Left Right">' . $Lcols2[3] . '</td>' . "\n";
				echo '</tr>' . "\n";
				echo '</tbody>' . "\n";
				$needheading = false;
				echo '<tbody>' . "\n";
			}
			echo '<tr class = "taC">' . "\n";
			for ($col=0; $col<$columns; $col++) {
				$data = $csvarray[$row][$col];      
				if ($col == 0) {
					$pmo = substr($data, 5, 2);
					$pda = substr($data, strrpos($data,"-")+1, 2);
					$pyr = substr($data, 0, 4);
					$tdate = AddDate($pmo, $pda, $pyr, 0); // just to get the name of the day
					if ($row !== count($csvarray) - 1) {  // ie not the last row
						if (substr($data, 0, 7) !== substr($csvarray[$row+1][0], 0, 7)) $needheading = true;
					}
					$data = '<td class = "date">' . substr($tdate[weekday], 0, 3) . '</td><td class = "date"><a href="' . $PHP_SELF . '?ID=' . $WUID . '&amp;month=' . $pmo . '&amp;day=' .$pda . '&amp;year=' . $pyr . '&amp;mode=1&amp;units=' . $units . '">' . $pda . '</a></td>';  //Date/Time
				}
				if ($col == 1) {
					$convarray = convertTemps($data);
					$data = merge_data($convarray);        // Figures out which measurement is desired & returns it
					$data =  '<td class="BodyDk Left">' . $data . '</td>';  // Temp
				}
				if ($col == 2) {
					$convarray = convertTemps($data);
					$data = merge_data($convarray);        	
					$data =  '<td class="BodyDk">' . $data . '</td>';
				}
				if ($col == 3) {
					$convarray = convertTemps($data);
					$data = merge_data($convarray);        		
					$data =  '<td class="BodyDk Right">' . $data . '</td>';
				}
				if ($col == 4 || $col == 5 || $col == 6) {      // DP
					$convarray = convertTemps($data);
					$data = merge_data($convarray);        		
					$data =  '<td>' . $data . '</td>';  
				}
				if ($col == 7) $data =  '<td class="BodyDk Left">' . $data . '</td>';        // Humidity
				if ($col == 8) $data =  '<td class="BodyDk">' . $data . '</td>';
				if ($col == 9) $data =  '<td class="BodyDk Right">' . $data . '</td>';
				if ($col == 10 || $col == 11) {                                               // Baro
					$convarray = convertBaro($data);
					$data = merge_data($convarray);        		
					$data =  '<td>' . $data . '</td>'; 
				}                          
				if ($col == 12) {                   // Wind
					$convarray = convertWind($data);
					$data = merge_data($convarray);        		
					$data =  '<td class="BodyDk Left">' . $data . '</td>';  
				}      
				if ($col == 13) {
					$convarray = convertWind($data);
					$data = merge_data($convarray);        					
					$data =  '<td class="BodyDk Right">' . $data . '</td>';
				}
				if ($col == 14) {                       // Gust
					$convarray = convertWind($data);
					$data = merge_data($convarray);        								
					$data =  '<td>' . $data . '</td>';  
				}                         
				if ($col == 15) {                        // Rain
					$convarray = convertRain($data);
					$data = merge_data($convarray);        											
					$data =  '<td class="BodyDk Left Right">' . $data . '</td>';  
				}
				echo $data;
			} // Columns
			echo '</tr>';
			if ($needheading) {
				echo '</tbody>';
				echo '</table>';			
			}
		} // Rows
		echo '</tbody>';
		echo '</table>';
	}
		echo '<table cellspacing="0" cellpadding="10" class="center noprint">' . "\n";
			echo '<tr>' . "\n";
			echo '<td id="csvLink" class="taC" style="width: 50%;"><a href="javascript:void(window.open(\'' . $wunderCSVstring . '\'))" class="subLink">' . $Lcommafile . '</a></td>' . "\n";
			echo '</tr>' . "\n";
		echo '</table>' . "\n";
		echo '</div>' . "\n";  //<!-- class="colorBox" -->
		echo '<table cellspacing="0" cellpadding="0" class="colorBottom">' . "\n";
			echo '<tr>' . "\n";
			echo '<td class= "bLeft"><div></div></td>' . "\n";
			echo '<td class= "bCenter full"><div></div></td>' . "\n";
			echo '<td class= "bRight"><div></div></td>' . "\n";
			echo '</tr>' . "\n";
		echo '</table>' . "\n";
 } // End of skipping tabular data 
	echo '</div>' . "\n";  //<!-- class="colorBox" -->
// <!-- blue credits bar -->
if ($toTop == 1) {       // Optional link to top of the page
	echo '<div class="pageTop noprint"><a href="#">' . $LtopPg . '</a></div>';
}
if ($footer and $LangFtext <> '') {  
	echo '<div class="bottomBar">' . $LangFtext . '</div>';
}
?>  
	<p align="center"></br>WU-History script by <a href="http://jcweather.us/scripts.php"> Jim McMurry</a></p>
	<table class="center tm20 noprint">
		<tr>
			<td class = "logo"></td>
			<td><?php echo $Lthanks . ' '; ?><a href="http://www.wunderground.com"> Weather Underground</a></td>
		</tr>
	</table>
  </td>
</tr>
</table>
</div>  <!-- id="wuwrap" -->
<?php
// End of the script all functions follow

function merge_data($arr) { // Takes an array and returns data in the proper units
global $units;
	if ($units == "M") {
		$data = $arr[0];
	} elseif ($units == "E"){
		$data =$arr[1];				
	} else {
		$data = $arr[1] . " / &nbsp;" . $arr[0];
	}
return $data;	
}

function col_stats($arr, $col) {
//Returns array $return with Hi Lo & Ave in [0],[1]&[2]
	$hi=$arr[0][$col];
	$lo=$arr[0][$col];
	$tot=0;
	for ($row=0; $row<count($arr); $row++) {
		$tot = $tot + $arr[$row][$col];
		if ($arr[$row][$col] > $hi) $hi=$arr[$row][$col];
		if ($arr[$row][$col] < $lo) $lo=$arr[$row][$col];		
	}
	$return[0] = $hi;
	$return[1] = $lo;
	$return[2] = round($tot / count($arr),1);
	return $return;
}

function temp_stats($arr, $col) {
//Returns array $return with Hi Lo & Ave in [0],[1]&[2]
//Each of those is an array with C in 0 and F in 1
	$hi=$arr[0][$col];
	$lo=$arr[0][$col];
	$tot=0;
	for ($row=0; $row<count($arr); $row++) {
		$tot = $tot + $arr[$row][$col];
		if ($arr[$row][$col] > $hi) $hi=$arr[$row][$col];
		if ($arr[$row][$col] < $lo) $lo=$arr[$row][$col];		
	}
	$return[0] = convertTemps($hi);
	$return[1] = convertTemps($lo);
	$return[2] = convertTemps(round($tot / count($arr),1));
	return $return;
}
   
function convertTemps($raw) {
// Returns an array with C in [0] and F in [1]
global $rawunits;
if ($rawunits == "english") {
	$return[0] = FtoC($raw,1);
	$return[1] = $raw;  
} else {
	$return[0] = $raw;
	$return[1] = CtoF($raw,1);
}
return $return;
}

function CtoF ($cTemp, $prec=0) {
	$prec = (integer)$prec;
	$fTemp = (float)(1.8 * $cTemp) + 32;
	return round($fTemp, $prec);
}

function FtoC ($fTemp, $prec=0) {
  $prec = (integer)$prec;
  $cTemp = (float)(($fTemp - 32) / 1.8 );
  return round($cTemp, $prec);
}

function baro_stats($arr, $col) {
//Returns array $return with Hi Lo & Ave in [0],[1]&[2]
//Each of those is an array with mb in 0 and inches in 1
	$hi=$arr[0][$col];
	$lo=$arr[0][$col];
	$tot=0;
	for ($row=0; $row<count($arr); $row++) {
		$tot = $tot + $arr[$row][$col];
		if ($arr[$row][$col] > $hi) $hi=$arr[$row][$col];
		if ($arr[$row][$col] < $lo) $lo=$arr[$row][$col];		
	}
	$return[0] = convertBaro($hi);
	$return[1] = convertBaro($lo);
	$return[2] = convertBaro(round($tot / count($arr),1));
	return $return;
}

function convertBaro($raw) {
// Returns an array with mb in [0] and inches in [1]
global $rawunits;
if ($rawunits == "english") {
	$return[0] = inTomb($raw,1);
	$return[1] = $raw;  
} else {
	$return[0] = $raw;
	$return[1] = mbToin($raw,1);
}
return $return;
}

function inTomb ($inch, $prec=0) {
  $prec = (integer)$prec;
  $mb = (float)$inch * 33.86;
  return round($mb, $prec);
}

function mbToin ($mb, $prec=0) {
  $prec = (integer)$prec;
  $in = (float)$mb / 33.86;
  return round($in, $prec);
}

function wind_stats($arr, $col) {
//Returns array $return with Hi Lo & Ave in [0],[1]&[2]
//Disregards 0 or "calm" entries
	$hi=$arr[0][$col];
	$lo=$arr[0][$col];
	$tot=0;
	$num=0;
	for ($row=0; $row<count($arr); $row++) {
		if ($arr[$row][$col] != 0) {
			$num++;
			$tot = $tot + $arr[$row][$col];
			if ($arr[$row][$col] > $hi) $hi=$arr[$row][$col]; 
			if ($arr[$row][$col] < $lo) $lo=$arr[$row][$col];	
		}
	}
	$return[0] = convertWind($hi);
	$return[1] = convertWind($lo);
	$return[2] = convertWind(round($tot / $num,1));
	return $return;
}

function convertWind($raw) {
// Returns an array with km in [0] and mi in [1]
global $rawunits;
if ($rawunits == "english") {
	$return[0] = miTokm($raw,1);
	$return[1] = $raw;  
} else {
	$return[0] = $raw;
	$return[1] = kmTomi($raw,1);
}
return $return;
}

function wDirAvg($arr) {
//Returns average wind direction
//Disregards 0 or "calm" entries
	$tot=0;
	$num=0;
	for ($row=0; $row<count($arr); $row++) {
		if ($arr[$row][6] != 0) {
			$num++;
			$tot = $tot + $arr[$row][5];
		}
	}
	return round($tot / $num,0);
}

function degTotxt ( $wind ) { 
  if ($wind >= 0 ) $return = "North"; 
  if ($wind > 10 ) $return = "NNE"; 
  if ($wind > 33 ) $return = "NE"; 
  if ($wind > 55 ) $return = "ENE"; 
  if ($wind > 78 ) $return = "East"; 
  if ($wind > 100 ) $return = "ESE"; 
  if ($wind > 123 ) $return = "SE"; 
  if ($wind > 145 ) $return = "SSE"; 
  if ($wind > 168 ) $return = "South"; 
  if ($wind > 190 ) $return = "SSW"; 
  if ($wind > 213 ) $return = "SW"; 
  if ($wind > 235 ) $return = "WSW"; 
  if ($wind > 258 ) $return = "West"; 
  if ($wind > 280 ) $return = "WNW"; 
  if ($wind > 303 ) $return = "NW"; 
  if ($wind > 325 ) $return = "NNW"; 
  if ($wind > 348 ) $return = "North"; 
  return $return;
}

function miTokm ($mile, $prec=0) {
  $prec = (integer)$prec;
  $km = (float)$mile * 1.6093;
  return round($km, $prec);
}

function kmTomi ($km, $prec=0) {
  $prec = (integer)$prec;
  $mi = (float)$km * .6213;
  return round($mi, $prec);
}

function total_rain($arr, $col) {
//Returns the total rain in a column in an array
$tot=0;
for ($row=0; $row<count($arr); $row++) {
	$tot = $tot + $arr[$row][$col];
}
$return = convertRain($tot);
return $return;
}

function convertRain($raw) {
// Returns an array with mm in [0] and inches in [1]
global $rawunits;
if ($rawunits == "english") {
	$return[0] = inTomm($raw, 1);
	$return[1] = $raw;  
} else {
	$return[0] = $raw;
	$return[1] = mmToin($raw, 2);
}
if ($return[0] < 0) {  // For Steve (Stumpy's) -990.00 data problem)
	$return[0] = 0;
	$return[1] = 0;	
}
return $return;
}

function inTomm ($inch, $prec=1) {
  $prec = (integer)$prec;
  $mm = (float)$inch * 25.4;
  return round($mm, $prec);
}

function mmToin ($mm, $prec=1) {
  $prec = (integer)$prec;
  $in = (float)$mm / 25.4;
  return round($in, $prec);
}

function AddDate ( $month, $day, $year, $numdays) {
	$nday = $day + $numdays;
	$newdate = mktime (0,0,0,$month,$nday,$year);
	return getdate($newdate);
}	
/*	Returns Array (
    [seconds] => 40
    [minutes] => 58
    [hours]   => 21
    [mday]    => 17
    [wday]    => 2
    [mon]     => 6
    [year]    => 2003
    [yday]    => 167
    [weekday] => Tuesday
    [month]   => June
    [0]       => 1055901520*/
	
function array_pure ($input) {  // Bad hack to pick out the lines w/o "\r\n" by picking known content
	$i = 0;
	while($i < count($input)) {
		if(  $input[$i][0][0] == "2" || $input[$i][0][0] == "T") {
			$return[] = $input[$i];
		}
	$i++;
	}
return $return;
} 

function getcsvWithoutHanging($url)   {
	$numberOfSeconds=4;    
	error_reporting(0);
	$url = str_replace("http://","",$url);
	$urlComponents = explode("/",$url);
	$domain = $urlComponents[0];
	$resourcePath = str_replace($domain,"",$url);
	$socketConnection = fsockopen($domain, 80, $errno, $errstr, $numberOfSeconds);
		$cols = '';
		fputs($socketConnection, "GET $resourcePath HTTP/1.0\r\nHost: $domain\r\nUser-agent: $UA\r\nConnection: close\r\n\r\n");
		$rows = 0;
		while (!feof($socketConnection)) {
			$line = ereg_replace("<br>", "", fgets($socketConnection, 4096));  //One of these gets left in there somehow
			$cols[] = explode(",", $line);
		}   
	fclose ($socketConnection);
	for ($i = 0; $i<=11;$i++) {  // Remove the header info that came with download
		array_shift($cols);
	}	
	return($cols);
} 

?>
